summaryrefslogtreecommitdiffstats
path: root/lib/kross/api/exception.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kross/api/exception.h')
-rw-r--r--lib/kross/api/exception.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/lib/kross/api/exception.h b/lib/kross/api/exception.h
index 6ee9597b..b0699bfb 100644
--- a/lib/kross/api/exception.h
+++ b/lib/kross/api/exception.h
@@ -22,7 +22,7 @@
#include "object.h"
-#include <qstring.h>
+#include <tqstring.h>
#include <ksharedptr.h>
namespace Kross { namespace Api {
@@ -51,7 +51,7 @@ namespace Kross { namespace Api {
* \param lineno The liner number in the scripting
* code where this exception got thrown.
*/
- Exception(const QString& error, long lineno = -1);
+ Exception(const TQString& error, long lineno = -1);
/**
* Destructor.
@@ -59,26 +59,26 @@ namespace Kross { namespace Api {
virtual ~Exception();
/// \see Kross::Api::Object::getClassName()
- virtual const QString getClassName() const;
+ virtual const TQString getClassName() const;
/// \see Kross::Api::Object::toString()
- virtual const QString toString();
+ virtual const TQString toString();
/**
* \return the error message.
*/
- const QString getError() const;
+ const TQString getError() const;
/**
* \return a more detailed tracemessage or QString::null if
* there is no trace avaiable.
*/
- const QString getTrace() const;
+ const TQString getTrace() const;
/**
* Set a more detailed tracemessage.
*/
- void setTrace(const QString& tracemessage);
+ void setTrace(const TQString& tracemessage);
/**
* \return the line number in the scripting code
@@ -89,9 +89,9 @@ namespace Kross { namespace Api {
private:
/// The error message.
- QString m_error;
+ TQString m_error;
/// The trace message.
- QString m_trace;
+ TQString m_trace;
/// The line number where the exception got thrown
long m_lineno;
};
@@ -59,26 +59,26 @@ namespace Kross { namespace Api {
/**
- * \return a more detailed tracemessage or QString::null if
+ * \return a more detailed tracemessage or TQString() if
* there is no trace avaiable.
*/